@@ -5,7 +5,9 @@ from .acm import ACM
 from .arxiv import Arxiv
 from .citeseerx import CiteSeerX
 from .cvf import CVF
+from .eccc import ECCC
 from .html import HTML
+from .iacr import IACR
 from .jmlr import JMLR
 from .local import LocalFile
 from .nature import Nature
@@ -28,6 +30,8 @@ providers = [
     Arxiv,
     CiteSeerX,
     CVF,
+    ECCC,
+    IACR,
     JMLR,
     Nature,
     NBER,
