@@ -20,6 +20,7 @@ from ..log import Logger
 from ..pdf_ops import prepare_pdf, blank_pdf, shrink_pdf
 from ..utils import (
     assert_file_is_pdf,
+    chdir,
     check_pdftool,
     download_url,
     follow_redirects,
@@ -141,13 +142,14 @@ class Provider(metaclass=abc.ABCMeta):
                 "%s failed to compress the PDF file." % self.pdftool
             )
 
-    def rewrite_pdf(self, in_pdf, out_pdf=None):
-        """Re-write the pdf using Ghostscript
+    def rewrite_pdf(self, in_file, out_pdf=None):
+        """Re-write the ps or pdf using Ghostscript
 
-        This helps avoid issues in dearxiv due to nested pdfs.
+        This helps avoid issues in dearxiv due to nested pdfs and enables
+        support for postscript files.
         """
         if out_pdf is None:
-            out_pdf = os.path.splitext(in_pdf)[0] + "-rewrite.pdf"
+            out_pdf = os.path.splitext(in_file)[0] + "-rewrite.pdf"
 
         status = subprocess.call(
             [
@@ -156,7 +158,7 @@ class Provider(metaclass=abc.ABCMeta):
                 "-dQUIET",
                 "-o",
                 out_pdf,
-                in_pdf,
+                in_file,
             ]
         )
         if not status == 0:
@@ -168,6 +170,7 @@ class Provider(metaclass=abc.ABCMeta):
     def uncompress_pdf(self, in_pdf, out_pdf):
         """ Uncompress a pdf file """
 
+        logger.info("Uncompressing with {self.pdftool} ...")
         if self.pdftool == "pdftk":
             status = subprocess.call(
                 [
@@ -211,33 +214,33 @@ class Provider(metaclass=abc.ABCMeta):
 
         self.initial_dir = os.getcwd()
         with tempfile.TemporaryDirectory(prefix="p2r_") as working_dir:
-            os.chdir(working_dir)
-            self.retrieve_pdf(pdf_url, tmp_filename)
+            with chdir(working_dir):
+                self.retrieve_pdf(pdf_url, tmp_filename)
 
-            assert_file_is_pdf(tmp_filename)
+                assert_file_is_pdf(tmp_filename)
 
-            intermediate_fname = tmp_filename
-            for opname, op in self.operations:
-                intermediate_fname = op(intermediate_fname)
+                intermediate_fname = tmp_filename
+                for opname, op in self.operations:
+                    intermediate_fname = op(intermediate_fname)
 
-            shutil.copy(intermediate_fname, clean_filename)
+                shutil.copy(intermediate_fname, clean_filename)
 
-            if self.debug:
-                print("Paused in debug mode in dir: %s" % working_dir)
-                print("Press enter to exit.")
-                return input()
+                if self.debug:
+                    print("Paused in debug mode in dir: %s" % working_dir)
+                    print("Press enter to exit.")
+                    return input()
 
-            if self.upload:
-                return upload_to_remarkable(
-                    clean_filename,
-                    remarkable_dir=self.remarkable_dir,
-                    rmapi_path=self.rmapi_path,
-                )
+                if self.upload:
+                    return upload_to_remarkable(
+                        clean_filename,
+                        remarkable_dir=self.remarkable_dir,
+                        rmapi_path=self.rmapi_path,
+                    )
+
+                target_path = os.path.join(self.initial_dir, clean_filename)
+                while os.path.exists(target_path):
+                    base = os.path.splitext(target_path)[0]
+                    target_path = base + "_.pdf"
+                shutil.move(clean_filename, target_path)
 
-            target_path = os.path.join(self.initial_dir, clean_filename)
-            while os.path.exists(target_path):
-                base = os.path.splitext(target_path)[0]
-                target_path = base + "_.pdf"
-            shutil.move(clean_filename, target_path)
-        os.chdir(self.initial_dir)
         return target_path
